# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import physics_pb2 as physics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cserver.proto\x12\x04lugo\x1a\rphysics.proto\"\x8e\x01\n\x0bJoinRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x18\n\x10protocol_version\x18\x02 \x01(\t\x12\"\n\tteam_side\x18\x03 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\x0e\n\x06number\x18\x04 \x01(\r\x12\"\n\rinit_position\x18\x05 \x01(\x0b\x32\x0b.lugo.Point\"\xbc\x02\n\x0cGameSnapshot\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\x12\x0c\n\x04turn\x18\x02 \x01(\r\x12\x1d\n\thome_team\x18\x03 \x01(\x0b\x32\n.lugo.Team\x12\x1d\n\taway_team\x18\x04 \x01(\x0b\x32\n.lugo.Team\x12\x18\n\x04\x62\x61ll\x18\x05 \x01(\x0b\x32\n.lugo.Ball\x12\x1f\n\x17turns_ball_in_goal_zone\x18\x06 \x01(\r\x12#\n\nshot_clock\x18\x07 \x01(\x0b\x32\x0f.lugo.ShotClock\"W\n\x05State\x12\x0b\n\x07WAITING\x10\x00\x12\r\n\tGET_READY\x10\x01\x12\r\n\tLISTENING\x10\x02\x12\x0b\n\x07PLAYING\x10\x03\x12\x0c\n\x08SHIFTING\x10\x04\x12\x08\n\x04OVER\x10\x63\"}\n\x04Team\x12\x1d\n\x07players\x18\x01 \x03(\x0b\x32\x0c.lugo.Player\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\r\x12\x1d\n\x04side\x18\x04 \x01(\x0e\x32\x0f.lugo.Team.Side\"\x1a\n\x04Side\x12\x08\n\x04HOME\x10\x00\x12\x08\n\x04\x41WAY\x10\x01\"H\n\tShotClock\x12\"\n\tteam_side\x18\x06 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\x17\n\x0fremaining_turns\x18\x07 \x01(\r\"\xa1\x01\n\x06Player\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x1d\n\x08position\x18\x02 \x01(\x0b\x32\x0b.lugo.Point\x12 \n\x08velocity\x18\x03 \x01(\x0b\x32\x0e.lugo.Velocity\x12\"\n\tteam_side\x18\x04 \x01(\x0e\x32\x0f.lugo.Team.Side\x12\"\n\rinit_position\x18\x05 \x01(\x0b\x32\x0b.lugo.Point\"e\n\x04\x42\x61ll\x12\x1d\n\x08position\x18\x01 \x01(\x0b\x32\x0b.lugo.Point\x12 \n\x08velocity\x18\x02 \x01(\x0b\x32\x0e.lugo.Velocity\x12\x1c\n\x06holder\x18\x03 \x01(\x0b\x32\x0c.lugo.Player\"\xab\x01\n\rOrderResponse\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1e.lugo.OrderResponse.StatusCode\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"[\n\nStatusCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\x0eUNKNOWN_PLAYER\x10\x01\x12\x11\n\rNOT_LISTENING\x10\x02\x12\x0e\n\nWRONG_TURN\x10\x03\x12\t\n\x05OTHER\x10\x63\"L\n\x08OrderSet\x12\x0c\n\x04turn\x18\x01 \x01(\r\x12\x1b\n\x06orders\x18\x02 \x03(\x0b\x32\x0b.lugo.Order\x12\x15\n\rdebug_message\x18\x03 \x01(\t\"\x83\x01\n\x05Order\x12\x1a\n\x04move\x18\x01 \x01(\x0b\x32\n.lugo.MoveH\x00\x12\x1c\n\x05\x63\x61tch\x18\x02 \x01(\x0b\x32\x0b.lugo.CatchH\x00\x12\x1a\n\x04kick\x18\x03 \x01(\x0b\x32\n.lugo.KickH\x00\x12\x1a\n\x04jump\x18\x04 \x01(\x0b\x32\n.lugo.JumpH\x00\x42\x08\n\x06\x61\x63tion\"(\n\x04Move\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity\"\x07\n\x05\x43\x61tch\"(\n\x04Kick\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity\"(\n\x04Jump\x12 \n\x08velocity\x18\x01 \x01(\x0b\x32\x0e.lugo.Velocity2o\n\x04Game\x12\x34\n\tJoinATeam\x12\x11.lugo.JoinRequest\x1a\x12.lugo.GameSnapshot0\x01\x12\x31\n\nSendOrders\x12\x0e.lugo.OrderSet\x1a\x13.lugo.OrderResponseB#Z!github.com/lugobots/lugo4go/protob\x06proto3')



_JOINREQUEST = DESCRIPTOR.message_types_by_name['JoinRequest']
_GAMESNAPSHOT = DESCRIPTOR.message_types_by_name['GameSnapshot']
_TEAM = DESCRIPTOR.message_types_by_name['Team']
_SHOTCLOCK = DESCRIPTOR.message_types_by_name['ShotClock']
_PLAYER = DESCRIPTOR.message_types_by_name['Player']
_BALL = DESCRIPTOR.message_types_by_name['Ball']
_ORDERRESPONSE = DESCRIPTOR.message_types_by_name['OrderResponse']
_ORDERSET = DESCRIPTOR.message_types_by_name['OrderSet']
_ORDER = DESCRIPTOR.message_types_by_name['Order']
_MOVE = DESCRIPTOR.message_types_by_name['Move']
_CATCH = DESCRIPTOR.message_types_by_name['Catch']
_KICK = DESCRIPTOR.message_types_by_name['Kick']
_JUMP = DESCRIPTOR.message_types_by_name['Jump']
_GAMESNAPSHOT_STATE = _GAMESNAPSHOT.enum_types_by_name['State']
_TEAM_SIDE = _TEAM.enum_types_by_name['Side']
_ORDERRESPONSE_STATUSCODE = _ORDERRESPONSE.enum_types_by_name['StatusCode']
JoinRequest = _reflection.GeneratedProtocolMessageType('JoinRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINREQUEST,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.JoinRequest)
  })
_sym_db.RegisterMessage(JoinRequest)

GameSnapshot = _reflection.GeneratedProtocolMessageType('GameSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _GAMESNAPSHOT,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.GameSnapshot)
  })
_sym_db.RegisterMessage(GameSnapshot)

Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), {
  'DESCRIPTOR' : _TEAM,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Team)
  })
_sym_db.RegisterMessage(Team)

ShotClock = _reflection.GeneratedProtocolMessageType('ShotClock', (_message.Message,), {
  'DESCRIPTOR' : _SHOTCLOCK,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.ShotClock)
  })
_sym_db.RegisterMessage(ShotClock)

Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
  'DESCRIPTOR' : _PLAYER,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Player)
  })
_sym_db.RegisterMessage(Player)

Ball = _reflection.GeneratedProtocolMessageType('Ball', (_message.Message,), {
  'DESCRIPTOR' : _BALL,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Ball)
  })
_sym_db.RegisterMessage(Ball)

OrderResponse = _reflection.GeneratedProtocolMessageType('OrderResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERRESPONSE,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.OrderResponse)
  })
_sym_db.RegisterMessage(OrderResponse)

OrderSet = _reflection.GeneratedProtocolMessageType('OrderSet', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSET,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.OrderSet)
  })
_sym_db.RegisterMessage(OrderSet)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Order)
  })
_sym_db.RegisterMessage(Order)

Move = _reflection.GeneratedProtocolMessageType('Move', (_message.Message,), {
  'DESCRIPTOR' : _MOVE,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Move)
  })
_sym_db.RegisterMessage(Move)

Catch = _reflection.GeneratedProtocolMessageType('Catch', (_message.Message,), {
  'DESCRIPTOR' : _CATCH,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Catch)
  })
_sym_db.RegisterMessage(Catch)

Kick = _reflection.GeneratedProtocolMessageType('Kick', (_message.Message,), {
  'DESCRIPTOR' : _KICK,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Kick)
  })
_sym_db.RegisterMessage(Kick)

Jump = _reflection.GeneratedProtocolMessageType('Jump', (_message.Message,), {
  'DESCRIPTOR' : _JUMP,
  '__module__' : 'server_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Jump)
  })
_sym_db.RegisterMessage(Jump)

_GAME = DESCRIPTOR.services_by_name['Game']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _JOINREQUEST._serialized_start=38
  _JOINREQUEST._serialized_end=180
  _GAMESNAPSHOT._serialized_start=183
  _GAMESNAPSHOT._serialized_end=499
  _GAMESNAPSHOT_STATE._serialized_start=412
  _GAMESNAPSHOT_STATE._serialized_end=499
  _TEAM._serialized_start=501
  _TEAM._serialized_end=626
  _TEAM_SIDE._serialized_start=600
  _TEAM_SIDE._serialized_end=626
  _SHOTCLOCK._serialized_start=628
  _SHOTCLOCK._serialized_end=700
  _PLAYER._serialized_start=703
  _PLAYER._serialized_end=864
  _BALL._serialized_start=866
  _BALL._serialized_end=967
  _ORDERRESPONSE._serialized_start=970
  _ORDERRESPONSE._serialized_end=1141
  _ORDERRESPONSE_STATUSCODE._serialized_start=1050
  _ORDERRESPONSE_STATUSCODE._serialized_end=1141
  _ORDERSET._serialized_start=1143
  _ORDERSET._serialized_end=1219
  _ORDER._serialized_start=1222
  _ORDER._serialized_end=1353
  _MOVE._serialized_start=1355
  _MOVE._serialized_end=1395
  _CATCH._serialized_start=1397
  _CATCH._serialized_end=1404
  _KICK._serialized_start=1406
  _KICK._serialized_end=1446
  _JUMP._serialized_start=1448
  _JUMP._serialized_end=1488
  _GAME._serialized_start=1490
  _GAME._serialized_end=1601
# @@protoc_insertion_point(module_scope)
