# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import server_pb2 as server__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62roadcast.proto\x12\x04lugo\x1a\x0cserver.proto\"\x1e\n\x0eWatcherRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"$\n\x0cStartRequest\x12\x14\n\x0cwatcher_uuid\x18\x01 \x01(\t\"\xfa\x02\n\tGameEvent\x12)\n\rgame_snapshot\x18\x01 \x01(\x0b\x32\x12.lugo.GameSnapshot\x12*\n\nnew_player\x18\x02 \x01(\x0b\x32\x14.lugo.EventNewPlayerH\x00\x12,\n\x0blost_player\x18\x03 \x01(\x0b\x32\x15.lugo.EventLostPlayerH\x00\x12.\n\x0cstate_change\x18\x04 \x01(\x0b\x32\x16.lugo.EventStateChangeH\x00\x12\x1f\n\x04goal\x18\x05 \x01(\x0b\x32\x0f.lugo.EventGoalH\x00\x12(\n\tgame_over\x18\x06 \x01(\x0b\x32\x13.lugo.EventGameOverH\x00\x12\x30\n\nbreakpoint\x18\x07 \x01(\x0b\x32\x1a.lugo.EventDebugBreakpointH\x00\x12\x32\n\x0e\x64\x65\x62ug_released\x18\x08 \x01(\x0b\x32\x18.lugo.EventDebugReleasedH\x00\x42\x07\n\x05\x65vent\"\xfa\x02\n\tGameSetup\x12\x18\n\x10protocol_version\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65v_mode\x18\x02 \x01(\x08\x12\x30\n\nstart_mode\x18\x03 \x01(\x0e\x32\x1c.lugo.GameSetup.StartingMode\x12\x35\n\x0elistening_mode\x18\x04 \x01(\x0e\x32\x1d.lugo.GameSetup.ListeningMode\x12\x1a\n\x12listening_duration\x18\x05 \x01(\r\x12\x15\n\rgame_duration\x18\x06 \x01(\r\x12%\n\thome_team\x18\x08 \x01(\x0b\x32\x12.lugo.TeamSettings\x12%\n\taway_team\x18\t \x01(\x0b\x32\x12.lugo.TeamSettings\"%\n\x0cStartingMode\x12\x0b\n\x07NO_WAIT\x10\x00\x12\x08\n\x04WAIT\x10\x01\"0\n\rListeningMode\x12\t\n\x05TIMER\x10\x00\x12\x08\n\x04RUSH\x10\x01\x12\n\n\x06REMOTE\x10\x02\"N\n\x0cTeamSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x02 \x01(\t\x12 \n\x06\x63olors\x18\x03 \x01(\x0b\x32\x10.lugo.TeamColors\"R\n\nTeamColors\x12 \n\x07primary\x18\x01 \x01(\x0b\x32\x0f.lugo.TeamColor\x12\"\n\tsecondary\x18\x02 \x01(\x0b\x32\x0f.lugo.TeamColor\"5\n\tTeamColor\x12\x0b\n\x03red\x18\x01 \x01(\r\x12\r\n\x05green\x18\x02 \x01(\r\x12\x0c\n\x04\x62lue\x18\x04 \x01(\r\".\n\x0e\x45ventNewPlayer\x12\x1c\n\x06player\x18\x01 \x01(\x0b\x32\x0c.lugo.Player\"/\n\x0f\x45ventLostPlayer\x12\x1c\n\x06player\x18\x01 \x01(\x0b\x32\x0c.lugo.Player\"q\n\x10\x45ventStateChange\x12\x30\n\x0eprevious_state\x18\x01 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\x12+\n\tnew_state\x18\x02 \x01(\x0e\x32\x18.lugo.GameSnapshot.State\"*\n\tEventGoal\x12\x1d\n\x04side\x18\x01 \x01(\x0e\x32\x0f.lugo.Team.Side\"\x0f\n\rEventGameOver\"u\n\x14\x45ventDebugBreakpoint\x12\x39\n\nbreakpoint\x18\x01 \x01(\x0e\x32%.lugo.EventDebugBreakpoint.Breakpoint\"\"\n\nBreakpoint\x12\n\n\x06ORDERS\x10\x00\x12\x08\n\x04TURN\x10\x01\"\x14\n\x12\x45ventDebugReleased2\xa8\x01\n\tBroadcast\x12\x32\n\x07OnEvent\x12\x14.lugo.WatcherRequest\x1a\x0f.lugo.GameEvent0\x01\x12\x35\n\x0cGetGameSetup\x12\x14.lugo.WatcherRequest\x1a\x0f.lugo.GameSetup\x12\x30\n\tStartGame\x12\x12.lugo.StartRequest\x1a\x0f.lugo.GameSetupB#Z!github.com/lugobots/lugo4go/protob\x06proto3')



_WATCHERREQUEST = DESCRIPTOR.message_types_by_name['WatcherRequest']
_STARTREQUEST = DESCRIPTOR.message_types_by_name['StartRequest']
_GAMEEVENT = DESCRIPTOR.message_types_by_name['GameEvent']
_GAMESETUP = DESCRIPTOR.message_types_by_name['GameSetup']
_TEAMSETTINGS = DESCRIPTOR.message_types_by_name['TeamSettings']
_TEAMCOLORS = DESCRIPTOR.message_types_by_name['TeamColors']
_TEAMCOLOR = DESCRIPTOR.message_types_by_name['TeamColor']
_EVENTNEWPLAYER = DESCRIPTOR.message_types_by_name['EventNewPlayer']
_EVENTLOSTPLAYER = DESCRIPTOR.message_types_by_name['EventLostPlayer']
_EVENTSTATECHANGE = DESCRIPTOR.message_types_by_name['EventStateChange']
_EVENTGOAL = DESCRIPTOR.message_types_by_name['EventGoal']
_EVENTGAMEOVER = DESCRIPTOR.message_types_by_name['EventGameOver']
_EVENTDEBUGBREAKPOINT = DESCRIPTOR.message_types_by_name['EventDebugBreakpoint']
_EVENTDEBUGRELEASED = DESCRIPTOR.message_types_by_name['EventDebugReleased']
_GAMESETUP_STARTINGMODE = _GAMESETUP.enum_types_by_name['StartingMode']
_GAMESETUP_LISTENINGMODE = _GAMESETUP.enum_types_by_name['ListeningMode']
_EVENTDEBUGBREAKPOINT_BREAKPOINT = _EVENTDEBUGBREAKPOINT.enum_types_by_name['Breakpoint']
WatcherRequest = _reflection.GeneratedProtocolMessageType('WatcherRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHERREQUEST,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.WatcherRequest)
  })
_sym_db.RegisterMessage(WatcherRequest)

StartRequest = _reflection.GeneratedProtocolMessageType('StartRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTREQUEST,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.StartRequest)
  })
_sym_db.RegisterMessage(StartRequest)

GameEvent = _reflection.GeneratedProtocolMessageType('GameEvent', (_message.Message,), {
  'DESCRIPTOR' : _GAMEEVENT,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.GameEvent)
  })
_sym_db.RegisterMessage(GameEvent)

GameSetup = _reflection.GeneratedProtocolMessageType('GameSetup', (_message.Message,), {
  'DESCRIPTOR' : _GAMESETUP,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.GameSetup)
  })
_sym_db.RegisterMessage(GameSetup)

TeamSettings = _reflection.GeneratedProtocolMessageType('TeamSettings', (_message.Message,), {
  'DESCRIPTOR' : _TEAMSETTINGS,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.TeamSettings)
  })
_sym_db.RegisterMessage(TeamSettings)

TeamColors = _reflection.GeneratedProtocolMessageType('TeamColors', (_message.Message,), {
  'DESCRIPTOR' : _TEAMCOLORS,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.TeamColors)
  })
_sym_db.RegisterMessage(TeamColors)

TeamColor = _reflection.GeneratedProtocolMessageType('TeamColor', (_message.Message,), {
  'DESCRIPTOR' : _TEAMCOLOR,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.TeamColor)
  })
_sym_db.RegisterMessage(TeamColor)

EventNewPlayer = _reflection.GeneratedProtocolMessageType('EventNewPlayer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWPLAYER,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventNewPlayer)
  })
_sym_db.RegisterMessage(EventNewPlayer)

EventLostPlayer = _reflection.GeneratedProtocolMessageType('EventLostPlayer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLOSTPLAYER,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventLostPlayer)
  })
_sym_db.RegisterMessage(EventLostPlayer)

EventStateChange = _reflection.GeneratedProtocolMessageType('EventStateChange', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSTATECHANGE,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventStateChange)
  })
_sym_db.RegisterMessage(EventStateChange)

EventGoal = _reflection.GeneratedProtocolMessageType('EventGoal', (_message.Message,), {
  'DESCRIPTOR' : _EVENTGOAL,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventGoal)
  })
_sym_db.RegisterMessage(EventGoal)

EventGameOver = _reflection.GeneratedProtocolMessageType('EventGameOver', (_message.Message,), {
  'DESCRIPTOR' : _EVENTGAMEOVER,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventGameOver)
  })
_sym_db.RegisterMessage(EventGameOver)

EventDebugBreakpoint = _reflection.GeneratedProtocolMessageType('EventDebugBreakpoint', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDEBUGBREAKPOINT,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventDebugBreakpoint)
  })
_sym_db.RegisterMessage(EventDebugBreakpoint)

EventDebugReleased = _reflection.GeneratedProtocolMessageType('EventDebugReleased', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDEBUGRELEASED,
  '__module__' : 'broadcast_pb2'
  # @@protoc_insertion_point(class_scope:lugo.EventDebugReleased)
  })
_sym_db.RegisterMessage(EventDebugReleased)

_BROADCAST = DESCRIPTOR.services_by_name['Broadcast']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _WATCHERREQUEST._serialized_start=39
  _WATCHERREQUEST._serialized_end=69
  _STARTREQUEST._serialized_start=71
  _STARTREQUEST._serialized_end=107
  _GAMEEVENT._serialized_start=110
  _GAMEEVENT._serialized_end=488
  _GAMESETUP._serialized_start=491
  _GAMESETUP._serialized_end=869
  _GAMESETUP_STARTINGMODE._serialized_start=782
  _GAMESETUP_STARTINGMODE._serialized_end=819
  _GAMESETUP_LISTENINGMODE._serialized_start=821
  _GAMESETUP_LISTENINGMODE._serialized_end=869
  _TEAMSETTINGS._serialized_start=871
  _TEAMSETTINGS._serialized_end=949
  _TEAMCOLORS._serialized_start=951
  _TEAMCOLORS._serialized_end=1033
  _TEAMCOLOR._serialized_start=1035
  _TEAMCOLOR._serialized_end=1088
  _EVENTNEWPLAYER._serialized_start=1090
  _EVENTNEWPLAYER._serialized_end=1136
  _EVENTLOSTPLAYER._serialized_start=1138
  _EVENTLOSTPLAYER._serialized_end=1185
  _EVENTSTATECHANGE._serialized_start=1187
  _EVENTSTATECHANGE._serialized_end=1300
  _EVENTGOAL._serialized_start=1302
  _EVENTGOAL._serialized_end=1344
  _EVENTGAMEOVER._serialized_start=1346
  _EVENTGAMEOVER._serialized_end=1361
  _EVENTDEBUGBREAKPOINT._serialized_start=1363
  _EVENTDEBUGBREAKPOINT._serialized_end=1480
  _EVENTDEBUGBREAKPOINT_BREAKPOINT._serialized_start=1446
  _EVENTDEBUGBREAKPOINT_BREAKPOINT._serialized_end=1480
  _EVENTDEBUGRELEASED._serialized_start=1482
  _EVENTDEBUGRELEASED._serialized_end=1502
  _BROADCAST._serialized_start=1505
  _BROADCAST._serialized_end=1673
# @@protoc_insertion_point(module_scope)
