# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: physics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rphysics.proto\x12\x04lugo\"\x1e\n\x06Vector\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\":\n\x08Velocity\x12\x1f\n\tdirection\x18\x01 \x01(\x0b\x32\x0c.lugo.Vector\x12\r\n\x05speed\x18\x02 \x01(\x01\x42#Z!github.com/lugobots/lugo4go/protob\x06proto3')



_VECTOR = DESCRIPTOR.message_types_by_name['Vector']
_POINT = DESCRIPTOR.message_types_by_name['Point']
_VELOCITY = DESCRIPTOR.message_types_by_name['Velocity']
Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'physics_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Vector)
  })
_sym_db.RegisterMessage(Vector)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'physics_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Point)
  })
_sym_db.RegisterMessage(Point)

Velocity = _reflection.GeneratedProtocolMessageType('Velocity', (_message.Message,), {
  'DESCRIPTOR' : _VELOCITY,
  '__module__' : 'physics_pb2'
  # @@protoc_insertion_point(class_scope:lugo.Velocity)
  })
_sym_db.RegisterMessage(Velocity)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/lugobots/lugo4go/proto'
  _VECTOR._serialized_start=23
  _VECTOR._serialized_end=53
  _POINT._serialized_start=55
  _POINT._serialized_end=84
  _VELOCITY._serialized_start=86
  _VELOCITY._serialized_end=144
# @@protoc_insertion_point(module_scope)
